@@ -35,24 +35,38 @@ class GqlClientConnectionError(Exception):
         self.body = body
 
 
-schema_location = Path(gettempdir()) / "rely_schema.graphql"
+tmp_dir = Path(gettempdir())
+schema_location = tmp_dir / "rely_schema.graphql"
+support_templates_location = tmp_dir / "support_templates_v1.json"
+HOUR_IN_SECONDS = 60 * 60
 
 
-def gql_client(email, password, url, impersonate, refresh_schema):
+def gql_client(auth, url, impersonate, refresh_schema):
+
+    if ":" in auth:
+        email, password = auth.split(":", 2)
+        transport = RequestsHTTPTransport(
+            url=url,
+            verify=True,
+            retries=3,
+            auth=(email, password),
+            headers={"IMPERSONATE": impersonate},
+        )
+    else:
+        transport = RequestsHTTPTransport(
+            url=url,
+            verify=True,
+            retries=3,
+            # auth=(email, password),
+            headers={"IMPERSONATE": impersonate, "Authorization": f"Bearer {auth}"},
+        )
 
-    transport = RequestsHTTPTransport(
-        url=url,
-        verify=True,
-        retries=3,
-        auth=(email, password),
-        headers={"IMPERSONATE": impersonate},
-    )
     try:
 
         if schema_location.exists() and not refresh_schema:
             # refresh the schema at least every 60 minutes
             age_in_seconds = time.time() - schema_location.stat().st_mtime
-            if age_in_seconds < 60 * 60:
+            if age_in_seconds < HOUR_IN_SECONDS:
                 with open(schema_location) as f:
                     schema_str = f.read()
                 return Client(transport=transport, schema=schema_str)
@@ -64,9 +78,17 @@ def gql_client(email, password, url, impersonate, refresh_schema):
 
     except Exception:
         # Probably an authorisation error
-        response = requests.post(
-            url, auth=(email, password), headers={"IMPERSONATE": impersonate}
-        )
+        if ":" in auth:
+            email, password = auth.split(":", 2)
+
+            response = requests.post(
+                url, auth=(email, password), headers={"IMPERSONATE": impersonate}
+            )
+        else:
+            response = requests.post(
+                url,
+                headers={"IMPERSONATE": impersonate, "Authorization": f"Bearer {auth}"},
+            )
 
         try:
             body = response.json()
@@ -80,6 +102,19 @@ def gql_client(email, password, url, impersonate, refresh_schema):
         raise GqlClientConnectionError(body)
 
 
+def get_support_templates(url, refresh_schema):
+
+    if support_templates_location.exists() and not refresh_schema:
+        age_in_seconds = time.time() - schema_location.stat().st_mtime
+        if age_in_seconds < HOUR_IN_SECONDS:
+            with open(support_templates_location) as f:
+                return json.load(f)
+
+    path = "/".join(url.split("/")[:-2]) + "/cli/v1/support_templates/"
+    response = requests.get(path)
+    return response.json()
+
+
 def main():
 
     # Lookup config from config file
@@ -166,12 +201,13 @@ def main():
         if not set_args.auth:
             raise CliException("No auth details found")
 
-        if set_args.auth.count(":") != 1:
-            raise CliException(
-                "Incorrect auth format. Auth details must be of the form '<email>:<password>'."
-            )
+        # if set_args.auth.count(":") != 1:
+        #     raise CliException(
+        #         "Incorrect auth format. Auth details must be of the form '<email>:<password>'."
+        #     )
 
-        email, password = set_args.auth.split(":")
+        # email, password = set_args.auth.split(":")
+        auth = set_args.auth
 
         if not set_args.auth:
             raise CliException("No auth information available")
@@ -199,8 +235,9 @@ def main():
         with catchtime("CLIENT", set_args.debug):
             try:
                 client = gql_client(
-                    email,
-                    password,
+                    # email,
+                    # password,
+                    auth,
                     url=set_args.host,
                     impersonate=set_args.impersonate,
                     refresh_schema=set_args.refresh_schema,
@@ -208,8 +245,15 @@ def main():
             except GqlClientConnectionError as e:
                 raise CliException(str(e))
 
+        with catchtime("SUPPORT_TEMPLATES", set_args.debug):
+            support_templates = get_support_templates(
+                url=set_args.host, refresh_schema=set_args.refresh_schema
+            )
+
         with catchtime("RELY", set_args.debug):
-            rely = Rely(client, set_args.type, set_args.action, **kwargs)
+            rely = Rely(
+                client, support_templates, set_args.type, set_args.action, **kwargs
+            )
 
         with catchtime("ACTION", set_args.debug):
             result = rely.act()
